@@ -19,9 +19,6 @@ def setup_parser(parser, completions=False):
     parser.add_argument(
         "-i", "--install", action="store_true",
         help="install the package")
-    parser.add_argument(
-        "-s", "--search", action="store_true",
-        help="search for the package on PyPi")
     parser.add_argument(
         "-r", "--release", action="store_true",
         help="install as released package; if not set, package is installed "
@@ -47,16 +44,12 @@ def command(opts, parser, extra_arg_groups=None):
         # Prevent other rez.* loggers from printing debugs
         logging.getLogger('rez').setLevel(logging.INFO)
 
-    from rez.pip import pip_install_package, run_pip_command
+    from rez.pip import pip_install_package
     import warnings
 
-    if not (opts.search or opts.install):
-        parser.error("Expected one of: --install, --search")
-
-    if opts.search:
-        with run_pip_command(["search", opts.PACKAGE]) as p:
-            p.wait()
-        return
+    # a bit weird, but there used to be more options. Leave like this for now
+    if not opts.install:
+        parser.error("Expected one of: --install")
 
     if opts.pip_ver:
         with warnings.catch_warnings():
